@@ -26,7 +26,8 @@ def simple_gw_log_like(y_true,
                   x[:, 3],
                   x[:, 4],
                   x[:, 5],
-                  x[:, 6]],
+                  x[:, 6],
+                  x[:, 7]],
                  axis=1)
 
     x = tf.cast(x, tf.float64)
@@ -51,7 +52,7 @@ def simple_gw_log_like(y_true,
                           delta_t=dt,
                           epoch=[epoch] * y_mu.shape[0])
 
-    shifted_y_true, y_mu = matchedfilter.coalign_waveforms(template, data)
+    # shifted_y_true, y_mu = matchedfilter.coalign_waveforms(template, data)
 
     # shifted_y_true = shifted_y_true.data
     # y_mu = y_mu.data
@@ -62,10 +63,11 @@ def simple_gw_log_like(y_true,
     #                 scale=std[..., None])
     # return tf.reduce_sum(like.log_prob(y_mu), axis=1)
 
-    shifted_y_true = shifted_y_true
-    y_mu = y_mu
+    # shifted_y_true = shifted_y_true
+    # y_mu = y_mu
 
-    like = gw_log_like(y_mu, shifted_y_true)
+    # like = gw_log_like(y_mu, shifted_y_true)
+    like = gw_log_like(data, template)
 
     return like
 
@@ -107,7 +109,8 @@ def simple_gw_prior(x):
     # prior_dec = tfd.Uniform(0, 2*np.pi).log_prob(cos_dec)
     prior_dec = tfd.Uniform(-np.pi / 2, np.pi / 2).log_prob(x[:, 4])
     # hack am passing t =0.5
-    prior_time = tfd.Uniform(0.1, 1.).log_prob(x[:, -2])
-    prior_psi = tfd.Uniform(0, 2 * np.pi).log_prob(x[:, -1])
+    prior_time = tfd.Uniform(0.1, 1.).log_prob(x[:, 5])
+    prior_psi = tfd.Uniform(0, 2 * np.pi).log_prob(x[:, 6])
+    prior_phase = tfd.Uniform(0, 2 * np.pi).log_prob(x[:, 7])
     # prior_noise = tfd.Uniform(0.01, 0.2).log_prob(x[:, -1])
-    return prior_spin + prior_q + prior_ra + prior_dec + prior_time + prior_psi
+    return prior_spin + prior_q + prior_ra + prior_dec + prior_time + prior_psi + prior_phase
